BUAACrypto2024
===============

BUAACrypto2024 is an easy crypto packet for some crypto algorithm \


- 实现一些常见的数学、编码运算。比如：大素数的选取、大整数和字符串的相互转化、整数求逆、快速模幂等等。

- 实现简单的分组密码(SM4)，公钥密码(RSA)，散列函数(SHA-1)，数字签名(ELGamma)


[联系作者](1366244715@qq.com)






Installation / 安装
--------------------------

::

    pip install BUAACrypto2024



Usage / 使用
--------------------------
cal用于基本数学运算\
Basic_Code用于实现密码算法\
见实验报告了解详细说明


Further discussion / 更多
--------------------------